dg
=================================

Documentation for dg

A framework to keep track of dependencies in non-linear workflows

Execute

.. code::

    make html

in the docs directory. Your html documentation will be in docs/build/html/index.html